@@ -112,11 +112,11 @@ sub CustomerCompanyAdd {
     }
 
     # check needed stuff
-    for (qw(CustomerID UserID)) {
-        if ( !$Param{$_} ) {
+    for my $Needed (qw(CustomerID UserID)) {
+        if ( !$Param{$Needed} ) {
             $Kernel::OM->Get('Kernel::System::Log')->Log(
                 Priority => 'error',
-                Message  => "Need $_!"
+                Message  => "Need $Needed!"
             );
             return;
         }
@@ -667,7 +667,7 @@ Returns an array of hash references.
                 'Germany'        => 'Germany',
                 'United Kingdom' => 'United Kingdom',
                 'United States'  => 'United States',
-                ...
+                # ...
             },
         },
         {
